LoginLinkExpiredKindeError class

An exception raised when the login link expires during authentication.

This only shows up when InternalAdditionalParameters.supportsReauth is enabled during an authentication request.

Inheritance

Constructors

LoginLinkExpiredKindeError({String? message, required Map<Object?, Object?> details, StackTrace? stackTrace})

Properties

code String
Allows users to identify the exception from a short code-name
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The long form message of the exception.
finalinherited
reauthState String?
The state returned with the error when the login link expires.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace which provides information to the user about the call sequence that triggered an exception
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited