PortalUrlSubnav enum

The area of the portal you want the user to land on

Inheritance
Available extensions

Values

profile → const PortalUrlSubnav
const PortalUrlSubnav('profile')
organizationDetails → const PortalUrlSubnav
const PortalUrlSubnav('organization_details')
organizationPaymentDetails → const PortalUrlSubnav
const PortalUrlSubnav('organization_payment_details')
organizationPlanSelection → const PortalUrlSubnav
const PortalUrlSubnav('organization_plan_selection')
paymentDetails → const PortalUrlSubnav
const PortalUrlSubnav('payment_details')
planDetails → const PortalUrlSubnav
const PortalUrlSubnav('plan_details')
planSelection → const PortalUrlSubnav
const PortalUrlSubnav('plan_selection')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value to be used in URL parameters
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PortalUrlSubnav>
A constant List of the values in this enum, in order of their declaration.